@@ -17,7 +17,7 @@ class NatsStreamingEnv(Settings):
     )
 
     stan_client_id: str = Field(
-        ..., env="stan_client_id", vault_secret_path=None, vault_secret_key=None
+        ..., env="stan_client_id", vault_secret_path=VAULT_PATH, vault_secret_key="stan_cluster_id"
     )
 
     pod_name: str = Field(
@@ -93,8 +93,8 @@ class MongoEnv(Settings):
     name: str = Field(
         ...,
         env="mongo_name",
-        vault_secret_path=None,
-        vault_secret_key=None,
+        vault_secret_path=VAULT_PATH,
+        vault_secret_key="mongo_name",
     )
 
 
